@@ -1213,7 +1213,7 @@ sa_rc_t sa_buffer(sa_t *sa, sa_buffer_t id, size_t size)
             else
                 cp = (char *)realloc(sa->cpReadBuf, size);
             if (cp == NULL)
-                return SA_RC(SA_ERR_SYS);
+                return SA_RC(SA_ERR_MEM);
             sa->cpReadBuf = cp;
             sa->nReadSize = size;
         }
@@ -1234,7 +1234,7 @@ sa_rc_t sa_buffer(sa_t *sa, sa_buffer_t id, size_t size)
             else
                 cp = (char *)realloc(sa->cpWriteBuf, size);
             if (cp == NULL)
-                return SA_RC(SA_ERR_SYS);
+                return SA_RC(SA_ERR_MEM);
             sa->cpWriteBuf = cp;
             sa->nWriteSize = size;
         }
@@ -2076,7 +2076,7 @@ sa_rc_t sa_shutdown(sa_t *sa, char *flags)
 }
 
 /* receive data via socket */
-sa_rc_t sa_recv(sa_t *sa, char *buf, size_t buflen, size_t *bufdone, sa_addr_t **raddr)
+sa_rc_t sa_recv(sa_t *sa, sa_addr_t **raddr, char *buf, size_t buflen, size_t *bufdone)
 {
     sa_rc_t rv;
     union {
@@ -2138,7 +2138,7 @@ sa_rc_t sa_recv(sa_t *sa, char *buf, size_t buflen, size_t *bufdone, sa_addr_t *
 }
 
 /* send data via socket */
-sa_rc_t sa_send(sa_t *sa, const char *buf, size_t buflen, size_t *bufdone, sa_addr_t *raddr)
+sa_rc_t sa_send(sa_t *sa, sa_addr_t *raddr, const char *buf, size_t buflen, size_t *bufdone)
 {
     size_t n;
     fd_set fds;
@@ -2203,7 +2203,7 @@ sa_rc_t sa_sendf(sa_t *sa, sa_addr_t *raddr, const char *cpFmt, ...)
     if ((nBuf+1) > sizeof(caBuf)) {
         /* requires a larger buffer, so allocate dynamically */
         if ((cpBuf = (char *)malloc(nBuf+1)) == NULL)
-            return SA_RC(SA_ERR_SYS);
+            return SA_RC(SA_ERR_MEM);
     }
     else {
         /* fits into small buffer, so allocate statically */
@@ -2214,7 +2214,7 @@ sa_rc_t sa_sendf(sa_t *sa, sa_addr_t *raddr, const char *cpFmt, ...)
     va_end(ap);
 
     /* pass-through to sa_send() */
-    rv = sa_send(sa, cpBuf, nBuf, NULL, raddr);
+    rv = sa_send(sa, raddr, cpBuf, nBuf, NULL);
 
     /* cleanup dynamically allocated buffer */
     if ((nBuf+1) > sizeof(caBuf))
