@@ -285,7 +285,7 @@ TS_TEST(test_sa_datagram)
         ex(SRV, sa_bind(sa_srv, saa_srv));
 
         /* communicate with client */
-        ex(SRV, sa_recv(sa_srv, buf_srv, sizeof(buf_srv), &l, &saa_clt));
+        ex(SRV, sa_recv(sa_srv, &saa_clt, buf_srv, sizeof(buf_srv), &l));
         if (strncmp(buf_srv, MSG_UDP_CLT_REQUEST, l) != 0)
             ts_test_fail(TS_CTX, "server: got \"%s\", expected \"%s\"",
                          buf_srv, MSG_UDP_CLT_REQUEST);
@@ -312,7 +312,7 @@ TS_TEST(test_sa_datagram)
         ex(CLT, sa_addr_u2a(saa_srv, "inet://127.0.0.1:12345#udp"));
         ex(CLT, sa_sendf(sa_clt, saa_srv, "%s", MSG_UDP_CLT_REQUEST));
         ex(CLT, sa_addr_destroy(saa_srv));
-        ex(CLT, sa_recv(sa_clt, buf_clt, sizeof(buf_clt), &l, &saa_srv));
+        ex(CLT, sa_recv(sa_clt, &saa_srv, buf_clt, sizeof(buf_clt), &l));
         if (strncmp(buf_clt, MSG_UDP_SRV_RESPONSE, l) != 0)
             ts_test_fail(TS_CTX, "client: got \"%s\", expected \"%s\"",
                          buf_clt, MSG_UDP_SRV_RESPONSE);
